The Pandeia engine is a 'simulation-hybrid' engine that performs calculations on two-dimensional astronomical scenes created by the user. It uses a pixel-based 3D approach, modeling both the spatial and wavelength dimensions using realistic PSFs for each instrument mode, and handles saturation, correlated read noise, and inter-pixel capacitance.

Installation and setup instructions (including a required data package) for Pandeia can be found at this Space Telescope Science Institute page: https://jwst-docs.stsci.edu/display/JPP/Installing+Pandeia

Usage guides for Pandeia can be found here: https://jwst-docs.stsci.edu/display/JPP/JWST+ETC+Pandeia+Engine+Tutorial

Any questions about Pandeia should be directed to the JWST Help Desk at https://jwsthelp.stsci.edu.
